fn write_diagnostics(
target: &mut String,
severity: DiagnosticSeverity,
diags_count: u16,
)Expand description
Writes the diagnostic count directly to the target string, avoiding intermediate allocation.
fn write_diagnostics(
target: &mut String,
severity: DiagnosticSeverity,
diags_count: u16,
)Writes the diagnostic count directly to the target string, avoiding intermediate allocation.